[llvm-commits] CVS: llvm/lib/Transforms/Instrumentation/TraceValues.cpp

Alkis Evlogimenos alkis at cs.uiuc.edu
Tue Jan 25 08:24:08 PST 2005



Changes in directory llvm/lib/Transforms/Instrumentation:

TraceValues.cpp updated: 1.70 -> 1.71
---
Log message:

Add a dependency to the trace library so that it gets pulled in
automatically.


---
Diffs of the changes:  (+3 -1)

 TraceValues.cpp |    4 +++-
 1 files changed, 3 insertions(+), 1 deletion(-)


Index: llvm/lib/Transforms/Instrumentation/TraceValues.cpp
diff -u llvm/lib/Transforms/Instrumentation/TraceValues.cpp:1.70 llvm/lib/Transforms/Instrumentation/TraceValues.cpp:1.71
--- llvm/lib/Transforms/Instrumentation/TraceValues.cpp:1.70	Thu Sep 30 15:14:18 2004
+++ llvm/lib/Transforms/Instrumentation/TraceValues.cpp	Tue Jan 25 10:23:57 2005
@@ -118,9 +118,11 @@
   return new BasicBlockTracer();
 }
 
 // Add a prototype for external functions used by the tracing code.
 //
 void ExternalFuncs::doInitialization(Module &M) {
+  M.addLibrary("trace");
   const Type *SBP = PointerType::get(Type::SByteTy);
   const FunctionType *MTy =
     FunctionType::get(Type::IntTy, std::vector<const Type*>(1, SBP), true);
@@ -118,9 +118,11 @@
 }
 
-// Add a prototype for external functions used by the tracing code.
+// Add a prototype for external functions used by the tracing code and require
+// the trace library for this module.
 //
 void ExternalFuncs::doInitialization(Module &M) {






More information about the llvm-commits mailing list